# -*- coding: ISO-8859-1 -*-

############################################################################## 
## 2004, Arnulf Heimsbakk
## 
## THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
## AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
## IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
## ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE FOR 
## ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL 
## DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR 
## SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
## CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
## LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY 
## OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF 
## SUCH DAMAGE.
##
## Otherwise the GPL license: http://www.gnu.org/licenses/gpl.txt
##############################################################################

from PIL import Image, ImageDraw, ImageFilter

class Frame:
    def __init__(self, alpha=0):
        self.alpha = alpha
        self.name = "None"

    def __str__(self):
        return self.name
        
    def __call__(self, image):
        if not self.alpha and image.mode != 'RGB':
            return image.convert('RGB')
        return image

class ThinShadowFrame(Frame):
    def __init__(self, alpha=0):
        Frame.__init__(self, alpha)
        self.name = "Thin shadow"    

    def __call__(self, image):
        w, h = image.size
        
        frame = Image.new('RGBA', (w + 10, h + 10), (255,255,255,0))
    
        draw = ImageDraw.Draw(frame)
        draw.rectangle([2,2,w+6,h+6], outline=(200,200,200))
        draw.rectangle([3,3,w+7,h+7], outline=(100,100,100))
        draw.rectangle([4,4,w+8,h+8], outline=(200,200,200))
    
        frame = frame.filter(ImageFilter.SMOOTH())
    
        draw = ImageDraw.Draw(frame)
        
        draw.rectangle([3,3,w+5,h+5], outline=(220,220,220))
        draw.rectangle([4,4,w+6,h+6], outline=(200,200,200))
        draw.rectangle([3,3,w+6,h+6], outline=(0,0,0))

        frame.paste(image, (5, 5))
        
        if not self.alpha and frame.mode != 'RGB':
            frame = frame.convert('RGB')
        
        return frame

class ThinFrame(Frame):
    def __init__(self, alpha=0):
        Frame.__init__(self, alpha)
        self.name = "Thin"    

    def __call__(self, image):
        w, h = image.size
        
        frame = Image.new('RGBA', (w+2, h+2), (255,255,255,0))
        frame.paste(image, (1, 1))
        draw = ImageDraw.Draw(frame)
        draw.rectangle([0,0,w+1,h+1], outline=(64,64,64))
        
        if not self.alpha and frame.mode != 'RGB':
            frame = frame.convert('RGB')
        
        return frame

if __name__ == "__main__":
    f = Frame()
    print f
    print f("TEST")
